# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, constr

class Address(BaseModel):
    """
    Address: N3 and N4  # noqa: E501
    """
    address1: Optional[constr(strict=True, max_length=55, min_length=0)] = Field(default=None, description="Segment: N3, Element: N301, Notes: Required, Address Information")
    address2: Optional[constr(strict=True, max_length=55, min_length=0)] = Field(default=None, description="Segment: N3, Element: N302, Notes: Address Information")
    city: Optional[constr(strict=True, max_length=30, min_length=0)] = Field(default=None, description="Segment: N4, Element: N401, Notes: Required, city")
    state: Optional[constr(strict=True, max_length=2, min_length=0)] = Field(default=None, description="Segment: N4, Element: N402, Notes: state example: TN, WA")
    postal_code: Optional[constr(strict=True, max_length=15, min_length=0)] = Field(default=None, alias="postalCode", description="Segment: N4, Element: N403")
    country_code: Optional[StrictStr] = Field(default=None, alias="countryCode", description="Segment: N4, Element: N404")
    location_identifier: Optional[StrictStr] = Field(default=None, alias="locationIdentifier", description="Segment: N4, Element: N406")
    country_sub_division_code: Optional[StrictStr] = Field(default=None, alias="countrySubDivisionCode", description="Segment: N4, Element: N407, Notes: Country SubDivision Code")
    __properties = ["address1", "address2", "city", "state", "postalCode", "countryCode", "locationIdentifier", "countrySubDivisionCode"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Address:
        """Create an instance of Address from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Address:
        """Create an instance of Address from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Address.parse_obj(obj)

        _obj = Address.parse_obj({
            "address1": obj.get("address1"),
            "address2": obj.get("address2"),
            "city": obj.get("city"),
            "state": obj.get("state"),
            "postal_code": obj.get("postalCode"),
            "country_code": obj.get("countryCode"),
            "location_identifier": obj.get("locationIdentifier"),
            "country_sub_division_code": obj.get("countrySubDivisionCode")
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictStr
from cardscan_client.models.upload_parameters import UploadParameters

class GenerateCardUploadUrl200Response(BaseModel):
    """
    GenerateCardUploadUrl200Response
    """
    card_id: StrictStr = Field(...)
    scan_id: StrictStr = Field(...)
    upload_url: StrictStr = Field(default=..., description="The URL to upload the card image.")
    upload_parameters: UploadParameters = Field(...)
    __properties = ["card_id", "scan_id", "upload_url", "upload_parameters"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GenerateCardUploadUrl200Response:
        """Create an instance of GenerateCardUploadUrl200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of upload_parameters
        if self.upload_parameters:
            _dict['upload_parameters'] = self.upload_parameters.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GenerateCardUploadUrl200Response:
        """Create an instance of GenerateCardUploadUrl200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return GenerateCardUploadUrl200Response.parse_obj(obj)

        _obj = GenerateCardUploadUrl200Response.parse_obj({
            "card_id": obj.get("card_id"),
            "scan_id": obj.get("scan_id"),
            "upload_url": obj.get("upload_url"),
            "upload_parameters": UploadParameters.from_dict(obj.get("upload_parameters")) if obj.get("upload_parameters") is not None else None
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, conlist
from cardscan_client.models.match_score import MatchScore

class CardApiResponseDetails(BaseModel):
    """
    CardApiResponseDetails
    """
    group_number: Optional[MatchScore] = None
    member_number: Optional[MatchScore] = None
    payer_name: Optional[MatchScore] = None
    rx_bin: Optional[MatchScore] = None
    rx_pcn: Optional[MatchScore] = None
    member_name: Optional[MatchScore] = None
    dependent_names: Optional[conlist(MatchScore)] = None
    plan_name: Optional[MatchScore] = None
    plan_id: Optional[MatchScore] = None
    card_specific_id: Optional[MatchScore] = None
    __properties = ["group_number", "member_number", "payer_name", "rx_bin", "rx_pcn", "member_name", "dependent_names", "plan_name", "plan_id", "card_specific_id"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CardApiResponseDetails:
        """Create an instance of CardApiResponseDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of group_number
        if self.group_number:
            _dict['group_number'] = self.group_number.to_dict()
        # override the default output from pydantic by calling `to_dict()` of member_number
        if self.member_number:
            _dict['member_number'] = self.member_number.to_dict()
        # override the default output from pydantic by calling `to_dict()` of payer_name
        if self.payer_name:
            _dict['payer_name'] = self.payer_name.to_dict()
        # override the default output from pydantic by calling `to_dict()` of rx_bin
        if self.rx_bin:
            _dict['rx_bin'] = self.rx_bin.to_dict()
        # override the default output from pydantic by calling `to_dict()` of rx_pcn
        if self.rx_pcn:
            _dict['rx_pcn'] = self.rx_pcn.to_dict()
        # override the default output from pydantic by calling `to_dict()` of member_name
        if self.member_name:
            _dict['member_name'] = self.member_name.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in dependent_names (list)
        _items = []
        if self.dependent_names:
            for _item in self.dependent_names:
                if _item:
                    _items.append(_item.to_dict())
            _dict['dependent_names'] = _items
        # override the default output from pydantic by calling `to_dict()` of plan_name
        if self.plan_name:
            _dict['plan_name'] = self.plan_name.to_dict()
        # override the default output from pydantic by calling `to_dict()` of plan_id
        if self.plan_id:
            _dict['plan_id'] = self.plan_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of card_specific_id
        if self.card_specific_id:
            _dict['card_specific_id'] = self.card_specific_id.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CardApiResponseDetails:
        """Create an instance of CardApiResponseDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CardApiResponseDetails.parse_obj(obj)

        _obj = CardApiResponseDetails.parse_obj({
            "group_number": MatchScore.from_dict(obj.get("group_number")) if obj.get("group_number") is not None else None,
            "member_number": MatchScore.from_dict(obj.get("member_number")) if obj.get("member_number") is not None else None,
            "payer_name": MatchScore.from_dict(obj.get("payer_name")) if obj.get("payer_name") is not None else None,
            "rx_bin": MatchScore.from_dict(obj.get("rx_bin")) if obj.get("rx_bin") is not None else None,
            "rx_pcn": MatchScore.from_dict(obj.get("rx_pcn")) if obj.get("rx_pcn") is not None else None,
            "member_name": MatchScore.from_dict(obj.get("member_name")) if obj.get("member_name") is not None else None,
            "dependent_names": [MatchScore.from_dict(_item) for _item in obj.get("dependent_names")] if obj.get("dependent_names") is not None else None,
            "plan_name": MatchScore.from_dict(obj.get("plan_name")) if obj.get("plan_name") is not None else None,
            "plan_id": MatchScore.from_dict(obj.get("plan_id")) if obj.get("plan_id") is not None else None,
            "card_specific_id": MatchScore.from_dict(obj.get("card_specific_id")) if obj.get("card_specific_id") is not None else None
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool
from cardscan_client.models.create_card_request_backside import CreateCardRequestBackside

class CreateCardRequest(BaseModel):
    """
    CreateCardRequest
    """
    enable_backside_scan: Optional[StrictBool] = Field(default=False, description="Whether to enable backside scanning")
    enable_livescan: Optional[StrictBool] = Field(default=False, description="Whether to enable live scanning")
    backside: Optional[CreateCardRequestBackside] = None
    __properties = ["enable_backside_scan", "enable_livescan", "backside"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreateCardRequest:
        """Create an instance of CreateCardRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of backside
        if self.backside:
            _dict['backside'] = self.backside.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreateCardRequest:
        """Create an instance of CreateCardRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CreateCardRequest.parse_obj(obj)

        _obj = CreateCardRequest.parse_obj({
            "enable_backside_scan": obj.get("enable_backside_scan") if obj.get("enable_backside_scan") is not None else False,
            "enable_livescan": obj.get("enable_livescan") if obj.get("enable_livescan") is not None else False,
            "backside": CreateCardRequestBackside.from_dict(obj.get("backside")) if obj.get("backside") is not None else None
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr

class ScanMetadataVideoTrack(BaseModel):
    """
    Video track details  # noqa: E501
    """
    aspect_ratio: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="aspectRatio")
    device_id: Optional[StrictStr] = Field(default=None, alias="deviceId")
    frame_rate: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="frameRate")
    group_id: Optional[StrictStr] = Field(default=None, alias="groupId")
    height: Optional[StrictInt] = None
    resize_mode: Optional[StrictStr] = Field(default=None, alias="resizeMode")
    width: Optional[StrictInt] = None
    __properties = ["aspectRatio", "deviceId", "frameRate", "groupId", "height", "resizeMode", "width"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ScanMetadataVideoTrack:
        """Create an instance of ScanMetadataVideoTrack from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ScanMetadataVideoTrack:
        """Create an instance of ScanMetadataVideoTrack from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ScanMetadataVideoTrack.parse_obj(obj)

        _obj = ScanMetadataVideoTrack.parse_obj({
            "aspect_ratio": obj.get("aspectRatio"),
            "device_id": obj.get("deviceId"),
            "frame_rate": obj.get("frameRate"),
            "group_id": obj.get("groupId"),
            "height": obj.get("height"),
            "resize_mode": obj.get("resizeMode"),
            "width": obj.get("width")
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from typing import Any, Dict, Optional
from pydantic import BaseModel, Field, StrictStr
from cardscan_client.models.address import Address

class SubscriberDetails(BaseModel):
    """
    SubscriberDetails
    """
    member_id: Optional[StrictStr] = Field(default=None, description="The member ID of the subscriber.")
    firstname: Optional[StrictStr] = Field(default=None, description="The first name of the subscriber.")
    lastname: Optional[StrictStr] = Field(default=None, description="The last name of the subscriber.")
    middlename: Optional[StrictStr] = Field(default=None, description="The middle name of the subscriber.")
    gender: Optional[StrictStr] = Field(default=None, description="The gender of the subscriber.")
    address: Optional[Address] = None
    dob: Optional[date] = Field(default=None, description="The date of birth of the subscriber.")
    additional_properties: Dict[str, Any] = {}
    __properties = ["member_id", "firstname", "lastname", "middlename", "gender", "address", "dob"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SubscriberDetails:
        """Create an instance of SubscriberDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "additional_properties"
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of address
        if self.address:
            _dict['address'] = self.address.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SubscriberDetails:
        """Create an instance of SubscriberDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SubscriberDetails.parse_obj(obj)

        _obj = SubscriberDetails.parse_obj({
            "member_id": obj.get("member_id"),
            "firstname": obj.get("firstname"),
            "lastname": obj.get("lastname"),
            "middlename": obj.get("middlename"),
            "gender": obj.get("gender"),
            "address": Address.from_dict(obj.get("address")) if obj.get("address") is not None else None,
            "dob": obj.get("dob")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class EligibilityApiResponseEligibilityRequestSubscriber(BaseModel):
    """
    EligibilityApiResponseEligibilityRequestSubscriber
    """
    first_name: Optional[StrictStr] = Field(default=None, alias="firstName", description="The first name of the subscriber.")
    last_name: Optional[StrictStr] = Field(default=None, alias="lastName", description="The last name of the subscriber.")
    member_id: Optional[StrictStr] = Field(default=None, alias="memberId", description="The member ID of the subscriber.")
    dob: Optional[StrictStr] = Field(default=None, description="The date of birth of the subscriber.")
    __properties = ["firstName", "lastName", "memberId", "dob"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> EligibilityApiResponseEligibilityRequestSubscriber:
        """Create an instance of EligibilityApiResponseEligibilityRequestSubscriber from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> EligibilityApiResponseEligibilityRequestSubscriber:
        """Create an instance of EligibilityApiResponseEligibilityRequestSubscriber from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return EligibilityApiResponseEligibilityRequestSubscriber.parse_obj(obj)

        _obj = EligibilityApiResponseEligibilityRequestSubscriber.parse_obj({
            "first_name": obj.get("firstName"),
            "last_name": obj.get("lastName"),
            "member_id": obj.get("memberId"),
            "dob": obj.get("dob")
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from cardscan_client.models.eligibility_api_response_eligibility_request_subscriber import EligibilityApiResponseEligibilityRequestSubscriber
from cardscan_client.models.provider_dto import ProviderDto

class EligibilityApiResponseEligibilityRequest(BaseModel):
    """
    The eligibility request.  # noqa: E501
    """
    control_number: Optional[StrictStr] = Field(default=None, alias="controlNumber", description="The control number of the claim.")
    trading_partner_service_id: Optional[StrictStr] = Field(default=None, alias="tradingPartnerServiceId", description="The ID of the trading partner service.")
    provider: Optional[ProviderDto] = None
    subscriber: Optional[EligibilityApiResponseEligibilityRequestSubscriber] = None
    __properties = ["controlNumber", "tradingPartnerServiceId", "provider", "subscriber"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> EligibilityApiResponseEligibilityRequest:
        """Create an instance of EligibilityApiResponseEligibilityRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of provider
        if self.provider:
            _dict['provider'] = self.provider.to_dict()
        # override the default output from pydantic by calling `to_dict()` of subscriber
        if self.subscriber:
            _dict['subscriber'] = self.subscriber.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> EligibilityApiResponseEligibilityRequest:
        """Create an instance of EligibilityApiResponseEligibilityRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return EligibilityApiResponseEligibilityRequest.parse_obj(obj)

        _obj = EligibilityApiResponseEligibilityRequest.parse_obj({
            "control_number": obj.get("controlNumber"),
            "trading_partner_service_id": obj.get("tradingPartnerServiceId"),
            "provider": ProviderDto.from_dict(obj.get("provider")) if obj.get("provider") is not None else None,
            "subscriber": EligibilityApiResponseEligibilityRequestSubscriber.from_dict(obj.get("subscriber")) if obj.get("subscriber") is not None else None
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from cardscan_client.models.coverage_summary import CoverageSummary
from cardscan_client.models.payer_details import PayerDetails
from cardscan_client.models.plan_details import PlanDetails
from cardscan_client.models.service import Service
from cardscan_client.models.subscriber_details import SubscriberDetails

class EligibilitySummarizedResponse(BaseModel):
    """
    EligibilitySummarizedResponse
    """
    eligibility_request_id: Optional[StrictStr] = Field(default=None, description="The ID of the eligibility request.")
    subscriber_details: Optional[SubscriberDetails] = None
    payer_details: Optional[PayerDetails] = None
    plan_details: Optional[PlanDetails] = None
    coverage_summary: Optional[CoverageSummary] = None
    chiropractic: Optional[Service] = None
    emergency_room: Optional[Service] = None
    office_visit: Optional[Service] = None
    urgent_care: Optional[Service] = None
    hospital_outpatient: Optional[Service] = None
    __properties = ["eligibility_request_id", "subscriber_details", "payer_details", "plan_details", "coverage_summary", "chiropractic", "emergency_room", "office_visit", "urgent_care", "hospital_outpatient"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> EligibilitySummarizedResponse:
        """Create an instance of EligibilitySummarizedResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of subscriber_details
        if self.subscriber_details:
            _dict['subscriber_details'] = self.subscriber_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of payer_details
        if self.payer_details:
            _dict['payer_details'] = self.payer_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of plan_details
        if self.plan_details:
            _dict['plan_details'] = self.plan_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of coverage_summary
        if self.coverage_summary:
            _dict['coverage_summary'] = self.coverage_summary.to_dict()
        # override the default output from pydantic by calling `to_dict()` of chiropractic
        if self.chiropractic:
            _dict['chiropractic'] = self.chiropractic.to_dict()
        # override the default output from pydantic by calling `to_dict()` of emergency_room
        if self.emergency_room:
            _dict['emergency_room'] = self.emergency_room.to_dict()
        # override the default output from pydantic by calling `to_dict()` of office_visit
        if self.office_visit:
            _dict['office_visit'] = self.office_visit.to_dict()
        # override the default output from pydantic by calling `to_dict()` of urgent_care
        if self.urgent_care:
            _dict['urgent_care'] = self.urgent_care.to_dict()
        # override the default output from pydantic by calling `to_dict()` of hospital_outpatient
        if self.hospital_outpatient:
            _dict['hospital_outpatient'] = self.hospital_outpatient.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> EligibilitySummarizedResponse:
        """Create an instance of EligibilitySummarizedResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return EligibilitySummarizedResponse.parse_obj(obj)

        _obj = EligibilitySummarizedResponse.parse_obj({
            "eligibility_request_id": obj.get("eligibility_request_id"),
            "subscriber_details": SubscriberDetails.from_dict(obj.get("subscriber_details")) if obj.get("subscriber_details") is not None else None,
            "payer_details": PayerDetails.from_dict(obj.get("payer_details")) if obj.get("payer_details") is not None else None,
            "plan_details": PlanDetails.from_dict(obj.get("plan_details")) if obj.get("plan_details") is not None else None,
            "coverage_summary": CoverageSummary.from_dict(obj.get("coverage_summary")) if obj.get("coverage_summary") is not None else None,
            "chiropractic": Service.from_dict(obj.get("chiropractic")) if obj.get("chiropractic") is not None else None,
            "emergency_room": Service.from_dict(obj.get("emergency_room")) if obj.get("emergency_room") is not None else None,
            "office_visit": Service.from_dict(obj.get("office_visit")) if obj.get("office_visit") is not None else None,
            "urgent_care": Service.from_dict(obj.get("urgent_care")) if obj.get("urgent_care") is not None else None,
            "hospital_outpatient": Service.from_dict(obj.get("hospital_outpatient")) if obj.get("hospital_outpatient") is not None else None
        })
        return _obj





# coding: utf-8

"""
    CardScan API

    The official documentation for the CardScan API.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class WebsocketError(BaseModel):
    """
    WebsocketError
    """
    message: StrictStr = Field(default=..., description="A message describing the error.")
    type: StrictStr = Field(default=..., description="The type of error.")
    code: StrictStr = Field(default=..., description="The error code.")
    internal_error: Optional[StrictStr] = Field(default=None, description="The internal error message.")
    error: Optional[StrictStr] = Field(default=None, description="The type of the error (deprecated)")
    __properties = ["message", "type", "code", "internal_error", "error"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> WebsocketError:
        """Create an instance of WebsocketError from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> WebsocketError:
        """Create an instance of WebsocketError from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return WebsocketError.parse_obj(obj)

        _obj = WebsocketError.parse_obj({
            "message": obj.get("message"),
            "type": obj.get("type"),
            "code": obj.get("code"),
            "internal_error": obj.get("internal_error"),
            "error": obj.get("error")
        })
        return _obj


